<?php

function hompark_add_google_fonts() {

  wp_enqueue_style( 'poppins-google-fonts', 'https://fonts.googleapis.com/css?family=Poppins:400,600,800', false );
  wp_enqueue_style( 'playfair-google-fonts', 'https://fonts.googleapis.com/css?family=Playfair', false );

}

add_action( 'wp_enqueue_scripts', 'hompark_add_google_fonts' );

if ( ! function_exists( 'hompark_enqueue_styles_and_scripts' ) ) {
	/**
	 * This function enqueues the required css and js files.
	 *
	 * @return void
	 */
	function hompark_enqueue_styles_and_scripts() {
		/**
		 * Enqueue css files.
		 */
		wp_enqueue_style( 'font awesome', get_template_directory_uri() . '/css/fontawesome.min.css' );
		wp_enqueue_style( 'hompark-bundle', get_template_directory_uri() . '/css/bundle.min.css' );
		wp_enqueue_style( 'bootsrap', get_template_directory_uri() . '/css/bootstrap.min.css' );
		wp_enqueue_style( 'hompark-main-style', get_template_directory_uri() . '/css/style.css' );
		wp_enqueue_style( 'hompark-stylesheet', get_stylesheet_uri() );
		wp_add_inline_style( 'hompark-stylesheet', hompark_dynamic_css() );

		/**
		 * Enqueue javascript files.
		 */

		wp_enqueue_script( 'comments', get_template_directory_uri() . '/js/comments.js', array(), false, false );
		wp_enqueue_script( 'popper', get_template_directory_uri() . '/js/popper.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'hompark-bundle', get_template_directory_uri() . '/js/bundle.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'hompark-scripts', get_template_directory_uri() . '/js/scripts.js', array( 'jquery' ), false, true );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}



		$data = array(
			'pre_loader_typewriter' => [],
		);




		if( hompark_get_option( 'enable_preloader' ) ) {
			$typewriter_text = [];
			$text_rotater = hompark_get_option( 'pre_loader_text_rotater' );
			if( $text_rotater ) {
				foreach ( $text_rotater as $rotater ) {
					$typewriter_text[] = esc_html( $rotater['title'] );
				}
			}
			$data['pre_loader_typewriter'] = $typewriter_text;
		}


		$comment_data = array(
			'name'      => esc_html__( 'Name is required', 'hompark' ),
			'email'     => esc_html__( 'Email is required', 'hompark' ),
			'comment'   => esc_html__( 'Comment is required', 'hompark' ),

		);

		wp_localize_script( 'hompark-scripts', 'data', $data );
		wp_localize_script( 'comments', 'comment_data', $comment_data );
	}

	add_action( 'wp_enqueue_scripts', 'hompark_enqueue_styles_and_scripts', 10 );
}

if( !function_exists( 'hompark_dynamic_css' ) ) {
	function hompark_dynamic_css() {

		$styles = '';
		if( hompark_get_option( 'logo_height' ) ) {
			$logo_height = str_replace(' ', '', hompark_get_option( 'logo_height' ) );
			$logo_height = str_replace('px', '', $logo_height);
			$styles .= "
				body .navbar .container .upper-side .logo img{
					height: {$logo_height}px;
				}
			";
		}
		if( hompark_get_option( 'enable_dynamic_color' ) ) {

			$site_color = ( hompark_get_option( 'theme_color' ) ) ? hompark_get_option( 'theme_color' ) : '#9f8054';
			$site_color2 = ( hompark_get_option( 'theme_color2' ) ) ? hompark_get_option( 'theme_color2' ) : '#ebcfa7';
			$dark_color = ( hompark_get_option( 'dark_color' ) ) ? hompark_get_option( 'dark_color' ) : '#26282b';

			$styles .= "

        :root {
          --color-light: {$site_color2} !important;
          --color-brown: {$site_color} !important;
          --color-dark: {$dark_color} !important;
        }


			";
		}

    if( hompark_get_option( 'enable_google_fonts' ) ) {

        $primary_font = hompark_get_option( 'primary_font' );
        $secondary_font = hompark_get_option( 'secondary_font' );

        // Enqueue Google Fonts
        wp_enqueue_style( 'google-fonts', 'https://fonts.googleapis.com/css?family=' . urlencode( $primary_font ) . '|' . urlencode( $secondary_font ), array(), null );

        $styles .= "

            :root {
                --primary-font: '{$primary_font}', sans-serif !important;
                --secondary-font: '{$secondary_font}', sans-serif !important;
            }

        ";
    }



		return $styles;
	}
}

add_action( 'init', 'hompark_dynamic_css' );
add_action(
    'after_setup_theme',
    function() {
        add_theme_support( 'html5', [ 'script', 'style' ] );
    }
);
